<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:elml="http://www.elml.ch" xmlns="http://www.w3.org/1999/xhtml" version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema">
    <xsl:import href="../../../../core/presentation/online/elml.xsl"/>
    <!-- ***** Parameter definitions  *****-->
    <!--The name of this layout (=folder name of template folder!) -->
    <xsl:param name="layout" select="'olat'"/>
    <xsl:param name="css_framework" select="'yaml'"/>
    <!--If you would like to have a navigation, set this to "yes" else (eg. for content package CP format) to "no" -->
    <xsl:param name="use_navigation" select="'yes'"/>
    <!-- ***** Template definitions  ***** -->
    <xsl:template match="elml:book | elml:contributionInBook | elml:journalArticle | elml:newspaperArticle | elml:map | elml:conferencePaper | elml:publicationCorporateBody | elml:thesis | elml:patent | elml:videoFilmBroadcast | elml:websites | elml:eJournals | elml:mailLists | elml:personalMail | elml:cdRom">
        <xsl:param name="comment"/>
        <xsl:param name="furtherReading"/>
        <li>
            <xsl:if test="not($furtherReading)">
                <xsl:element name="a">
                    <xsl:attribute name="name">
                        <xsl:value-of select="generate-id(.)"/>
                    </xsl:attribute>
                    <xsl:attribute name="id">
                        <xsl:value-of select="generate-id(.)"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
            <xsl:if test="@title or @titleOfContribution">
                <i class="bibTitle">
                    <xsl:value-of select="@title"/>
                    <xsl:value-of select="@titleOfContribution"/>
                </i>
            </xsl:if>
            <br/>
            <xsl:choose>
                <xsl:when test="@volumeNr">
                    <xsl:text>Date: </xsl:text>
                    <xsl:value-of select="@volumeNr"/>
                    <xsl:if test="not(contains(@volumeNr,'200'))">
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="@publicationYear"/>
                    </xsl:if>
                    <br/>
                </xsl:when>
                <xsl:when test="@dayMonth">
                    <xsl:text>Date: </xsl:text>
                    <xsl:value-of select="@dayMonth"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="@publicationYear"/>
                    <br/>
                </xsl:when>
                <xsl:when test="@accessedDate | @datePlace">
                    <xsl:text>Date: </xsl:text>
                    <xsl:value-of select="@accessedDate"/>
                    <xsl:value-of select="@datePlace"/>
                    <br/>
                </xsl:when>
            </xsl:choose>
            <xsl:if test="@journalTitle | @newspaperTitle | @publisher | @proceedingsTitle">
                <xsl:text>From: </xsl:text>
                <xsl:value-of select="@journalTitle"/>
                <xsl:value-of select="@proceedingsTitle"/>
                <xsl:value-of select="@newspaperTitle"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="@publisher"/>
                <xsl:if test="@publicationPlace">
                    <xsl:text>, </xsl:text>
                    <xsl:value-of select="@publicationPlace"/>
                </xsl:if>
                <xsl:if test="@edition">
                    <xsl:text> (</xsl:text>
                    <xsl:value-of select="@edition"/>
                    <xsl:text> ed.)</xsl:text>
                </xsl:if>
                <br/>
            </xsl:if>
            <xsl:if test="@author">
                <xsl:text>Author: </xsl:text>
                <xsl:value-of select="@author"/>
                <br/>
            </xsl:if>
            <xsl:if test="@url">
                <xsl:text>Website: </xsl:text>
                <xsl:element name="a">
                    <xsl:attribute name="href">
                        <xsl:value-of select="@url"/>
                    </xsl:attribute>
                    <xsl:attribute name="target">
                        <xsl:text>_blank</xsl:text>
                    </xsl:attribute>
                    <xsl:attribute name="class">
                        <xsl:text>bibLink</xsl:text>
                    </xsl:attribute>
                    <xsl:value-of select="@url"/>
                </xsl:element>
                <br/>
            </xsl:if>
            <xsl:if test="@downloadUrl">
                <br/>
                <a target="_blank" class="lightwindow">
                    <xsl:attribute name="href">
                        <xsl:if test="starts-with(@downloadUrl, '..')">
                            <xsl:value-of select="$server"/>
                            <xsl:text>/</xsl:text>
                            <xsl:value-of select="/elml:lesson/@label"/>
                            <xsl:text>/</xsl:text>
                            <xsl:value-of select="$lang"/>
                            <xsl:text>/html/</xsl:text>
                        </xsl:if>
                        <xsl:value-of select="@downloadUrl"/>
                    </xsl:attribute>
                    <img alt="Download">
                        <xsl:attribute name="src">
                            <xsl:text>../../../_templates/</xsl:text>
                            <xsl:value-of select="$layout"/>
                            <xsl:text>/file_icons/osx/small/</xsl:text>
                            <xsl:choose>
                                <xsl:when test="ends-with(@downloadUrl,'.pdf')">
                                    <xsl:text>pdf</xsl:text>
                                </xsl:when>
                                <xsl:when test="ends-with(@downloadUrl,'.zip')">
                                    <xsl:text>zip</xsl:text>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>html</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:text>.png</xsl:text>
                        </xsl:attribute>
                    </img>
                </a>
                <br/>
            </xsl:if>
            <xsl:if test="text()">
                <span class="bibCommentSource">
                    <xsl:text> [</xsl:text>
                    <xsl:value-of select="text()"/>
                    <xsl:text>]</xsl:text>
                </span>
            </xsl:if>
            <xsl:if test="$comment">
                <br/>
                <xsl:value-of select="$comment"/>
            </xsl:if>
        </li>
    </xsl:template>
    <xsl:template match="elml:box">
        <xsl:param name="display">
            <xsl:call-template name="elml:display"/>
        </xsl:param>
        <xsl:if test="$display='yes'">
            <div class="b_toolboxes">
                <xsl:call-template name="elml:Label"/>
                <xsl:if test="@title">
                    <div class="b_toolbox_head_wrapper">
                        <div class="b_toolbox_head">
                            <div class="b_toolbox_head_icon b_toolbox_head_default">
                                <strong>
                                    <xsl:value-of select="@title"/>
                                </strong>
                            </div>
                        </div>
                    </div>
                </xsl:if>
                <xsl:if test="@icon and not($layout='none')">
                    <img src="../../../_templates/{$layout}/icons/{@icon}.gif" title="{@icon}" alt="{@icon}" class="icon"/>
                </xsl:if>
                <div class="b_toolbox_content">
                    <xsl:apply-templates/>
                    <br/>
                </div>
            </div>
            <br/>
        </xsl:if>
    </xsl:template>
    <xsl:template match="elml:link">
        <xsl:param name="label" select="@targetLabel"/>
        <xsl:param name="link_title">
            <xsl:value-of select="@size"/>
            <xsl:if test="@size and (@legend or @type)">
                <xsl:text> - </xsl:text>
            </xsl:if>
            <xsl:value-of select="@legend"/>
            <xsl:if test="@type and @legend">
                <xsl:text> - </xsl:text>
            </xsl:if>
            <xsl:if test="@type">
                <xsl:text>Filetype: </xsl:text>
            </xsl:if>
            <xsl:value-of select="@type"/>
        </xsl:param>
        <xsl:param name="TempURL">
            <xsl:choose>
                <xsl:when test="not((@role='student') or (@role=$role) or (not (@role)))">
                    <xsl:text>none</xsl:text>
                </xsl:when>
                <xsl:when test="@uri">
                    <xsl:if test="(@cssClass='lightwindow' or $lightwindow='yes') and starts-with(@uri, '..')">
                        <xsl:value-of select="$server"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="/elml:lesson/@label"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="$lang"/>
                        <xsl:text>/html/</xsl:text>
                    </xsl:if>
                    <xsl:value-of select="@uri"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:choose>
                        <xsl:when test="@targetLesson and not(@targetLesson = /elml:lesson/@label)">
                            <xsl:text>../../../</xsl:text>
                            <xsl:value-of select="@targetLesson"/>
                            <xsl:text>/</xsl:text>
                            <xsl:choose>
                                <xsl:when test="@targetLessonLang">
                                    <xsl:value-of select="@targetLessonLang"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$lang"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:text>/html/index</xsl:text>
                        </xsl:when>
                        <xsl:when test="not($pagebreak_level='unit') and not($pagebreak_level='lo')">
                            <xsl:text>index</xsl:text>
                        </xsl:when>
                        <xsl:when test="(name(//*[@label=$label])='unit') and (($pagebreak_level='unit') or ($pagebreak_level='lo'))">
                            <xsl:text>unit_</xsl:text>
                            <xsl:value-of select="@targetLabel"/>
                        </xsl:when>
                        <xsl:when test="(name(//*[@label=$label])='learningObject' or name(//*[@label=$label])='summary' or name(//*[@label=$label])='selfAssessment') and ($pagebreak_level='lo')">
                            <xsl:value-of select="//*[@label=$label]/../@label"/>
                            <xsl:text>_</xsl:text>
                            <xsl:value-of select="@targetLabel"/>
                        </xsl:when>
                        <xsl:when test="$pagebreak_level='lo'">
                            <xsl:choose>
                                <xsl:when test="//*[@label=$label]/ancestor::node()/name()='learningObject'">
                                    <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='unit']/@label"/>
                                    <xsl:text>_</xsl:text>
                                    <xsl:choose>
                                        <xsl:when test="//*[@label=$label]/ancestor::node()[name()='learningObject']/@label">
                                            <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='learningObject']/@label"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:text>learningObject</xsl:text>
                                            <xsl:value-of select="1+count(//*[@label=$label]/ancestor::node()[name()='learningObject']/preceding-sibling::node()[name()='learningObject']/name())"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:when test="//*[@label=$label]/ancestor::node()/name()='selfAssessment'">
                                    <xsl:choose>
                                        <xsl:when test="//*[@label=$label]/ancestor::node()/name()='unit'">
                                            <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='unit']/@label"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="/elml:lesson/@label"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:text>_</xsl:text>
                                    <xsl:choose>
                                        <xsl:when test="//*[@label=$label]/ancestor::node()[name()='selfAssessment']/@label">
                                            <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='selfAssessment']/@label"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:text>selfAssessment</xsl:text>
                                            <xsl:value-of select="1+count(//*[@label=$label]/ancestor::node()[name()='selfAssessment']/preceding-sibling::node()[name()='learningObject']/name())+count(//*[@label=$label]/ancestor::node()[name()='selfAssessment']/preceding-sibling::node()[name()='selfAssessment']/name())"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:when test="//*[@label=$label]/ancestor::node()/name()='summary'">
                                    <xsl:choose>
                                        <xsl:when test="//*[@label=$label]/ancestor::node()/name()='unit'">
                                            <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='unit']/@label"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="/elml:lesson/@label"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:text>_</xsl:text>
                                    <xsl:choose>
                                        <xsl:when test="//*[@label=$label]/ancestor::node()[name()='summary']/@label">
                                            <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='summary']/@label"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:text>summary</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:when test="//*[@label=$label]/ancestor::node()/name()='entry'">
                                    <xsl:choose>
                                        <xsl:when test="//*[@label=$label]/ancestor::node()/name()='unit'">
                                            <xsl:text>unit_</xsl:text>
                                            <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='unit']/@label"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:text>index</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:otherwise>index</xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:when test="$pagebreak_level='unit'">
                            <xsl:choose>
                                <xsl:when test="//*[@label=$label]/ancestor::node()[name()='unit'][1]/@label">
                                    <xsl:text>unit_</xsl:text>
                                    <xsl:value-of select="//*[@label=$label]/ancestor::node()[name()='unit'][1]/@label"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>index</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>index</xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:value-of select="$filename_suffix"/>
                    <xsl:if test="@targetLabel">
                        <xsl:choose>
                            <xsl:when test="$pagebreak_level='lo'">
                                <xsl:if test="not(//*[@label=$label]/name()='lesson' or //*[@label=$label]/name()='unit' or //*[@label=$label]/name()='learningObject' or //*[@label=$label]/name()='selfAssessment' or //*[@label=$label]/name()='summary')">
                                    <xsl:text>#</xsl:text>
                                    <xsl:choose>
                                        <xsl:when test="name(//*[@label=$label])='unit'">
                                            <xsl:text>unit_</xsl:text>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="//*[@label=$label]/../@label"/>
                                            <xsl:text>_</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:value-of select="@targetLabel"/>
                                    <xsl:value-of select="$filename_suffix"/>
                                </xsl:if>
                            </xsl:when>
                            <xsl:when test="$pagebreak_level='unit'">
                                <xsl:if test="not(//*[@label=$label]/parent::node()/name()='lesson')">
                                    <xsl:text>#</xsl:text>
                                    <xsl:choose>
                                        <xsl:when test="name(//*[@label=$label])='unit'">
                                            <xsl:text>unit_</xsl:text>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="//*[@label=$label]/../@label"/>
                                            <xsl:text>_</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:value-of select="@targetLabel"/>
                                    <xsl:value-of select="$filename_suffix"/>
                                </xsl:if>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>#</xsl:text>
                                <xsl:choose>
                                    <xsl:when test="name(//*[@label=$label])='unit'">
                                        <xsl:text>unit_</xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="//*[@label=$label]/../@label"/>
                                        <xsl:text>_</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:value-of select="@targetLabel"/>
                                <xsl:value-of select="$filename_suffix"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:param>
        <xsl:param name="inline">
            <xsl:call-template name="elml:inline"/>
        </xsl:param>
        <xsl:choose>
            <xsl:when test="$inline='no'">
                <xsl:if test="not(name(preceding-sibling::*[1])='link')">
                    <xsl:call-template name="elml:tableOpen"/>
                </xsl:if>
                <li>
                    <xsl:attribute name="class">
                        <xsl:choose>
                            <xsl:when test="@type">
                                <xsl:value-of select="lower-case(@type)"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>file</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:attribute>
                    <xsl:choose>
                        <xsl:when test="$TempURL='none'">
                            <xsl:apply-templates/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:element name="a">
                                <xsl:call-template name="elml:CSS_Class"/>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="$TempURL"/>
                                </xsl:attribute>
                                <xsl:if test="starts-with($TempURL, 'http') or ends-with($TempURL, '.pdf') or @target">
                                    <xsl:attribute name="target">
                                        <xsl:choose>
                                            <xsl:when test="starts-with($TempURL, 'http') or ends-with($TempURL, '.pdf')">
                                                <xsl:text>_blank</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="@target"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:attribute>
                                </xsl:if>
                                <xsl:attribute name="title">
                                    <xsl:value-of select="$link_title"/>
                                </xsl:attribute>
                                <xsl:apply-templates/>
                            </xsl:element>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:if test="@size">
                        <xsl:text> (</xsl:text>
                        <xsl:value-of select="@size"/>
                        <xsl:text>)</xsl:text>
                    </xsl:if>
                    <xsl:if test="@legend">
                        <xsl:text>: </xsl:text>
                        <xsl:value-of select="@legend"/>
                    </xsl:if>
                </li>
                <xsl:if test="not(name(following-sibling::*[1])='link')">
                    <xsl:call-template name="elml:tableClose"/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="$TempURL='none'">
                <xsl:apply-templates/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:element name="a">
                    <xsl:call-template name="elml:CSS_Class"/>
                    <xsl:attribute name="href">
                        <xsl:value-of select="$TempURL"/>
                    </xsl:attribute>
                    <xsl:if test="starts-with($TempURL, 'http') or ends-with($TempURL, '.pdf') or @target">
                        <xsl:attribute name="target">
                            <xsl:choose>
                                <xsl:when test="starts-with($TempURL, 'http') or ends-with($TempURL, '.pdf')">
                                    <xsl:text>_blank</xsl:text>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="@target"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:attribute>
                    </xsl:if>
                    <xsl:if test="@size or @type">
                        <xsl:attribute name="id">
                            <xsl:value-of select="$TempURL"/>
                            <xsl:value-of select="position()"/>
                        </xsl:attribute>
                        <xsl:attribute name="onmouseover">
                            <xsl:text>onInline('</xsl:text>
                            <xsl:value-of select="$TempURL"/>
                            <xsl:value-of select="position()"/>
                            <xsl:text>')</xsl:text>
                        </xsl:attribute>
                        <xsl:attribute name="onmouseout">
                            <xsl:text>off('</xsl:text>
                            <xsl:value-of select="$TempURL"/>
                            <xsl:value-of select="position()"/>
                            <xsl:text>')</xsl:text>
                        </xsl:attribute>
                    </xsl:if>
                    <xsl:choose>
                        <xsl:when test="@size or @type or @legend">
                            <xsl:attribute name="title">
                                <xsl:value-of select="$link_title"/>
                            </xsl:attribute>
                            <xsl:attribute name="caption">
                                <xsl:value-of select="text()"/>
                            </xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:attribute name="title">
                                <xsl:value-of select="text()"/>
                            </xsl:attribute>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:apply-templates/>
                </xsl:element>
                <xsl:if test="@size or @type or @legend">
                    <span style="display: none;">
                        <xsl:attribute name="id">
                            <xsl:value-of select="$TempURL"/>
                            <xsl:value-of select="position()"/>
                            <xsl:text>text</xsl:text>
                        </xsl:attribute>
                        <xsl:text> [</xsl:text>
                        <xsl:value-of select="$link_title"/>
                        <xsl:text>] </xsl:text>
                    </span>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="elml:tableOpen"> &#xE001;ul class="link_list"&#xE002; </xsl:template>
    <xsl:template name="elml:tableClose"> &#xE001;/ul&#xE002; </xsl:template>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$multiple='on'">
                <xsl:for-each select="document($config_file)/elml:config/elml:modules/elml:course[child::node()=$transformlesson_label]/elml:labelname">
                    <xsl:apply-templates select="document(concat(substring-before($config_file,'_config'),text(),'/',$lang,'/text/',text(),'.xml'))/elml:lesson"/>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="elml:manifest"/>
        <xsl:call-template name="elml:sitemap"/>
        <xsl:call-template name="elml:feed_rss"/>
        <xsl:call-template name="elml:feed_atom"/>
    </xsl:template>
    <xsl:template name="elml:LayoutHead">
        <head>
            <xsl:if test="//elml:multimedia/@type='mathml'">
                <xsl:processing-instruction name="xml-stylesheet"> href="http://www.w3.org/Math/XSL/mathml.xsl" type="text/xsl" </xsl:processing-instruction>
            </xsl:if>
            <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
            <meta http-equiv="Content-Script-Type" content="text/javascript"/>
            <meta name="description">
                <xsl:attribute name="content">
                    <xsl:value-of select="/elml:lesson/@title"/>
                    <xsl:if test="not(name()='lesson')">
                        <xsl:text>: </xsl:text>
                        <xsl:call-template name="elml:Kapitel_Title"/>
                    </xsl:if>
                    <xsl:text>. </xsl:text>
                    <xsl:choose>
                        <xsl:when test="name()='learningObject' or name()='summary' or name()='selfAssessment'">
                            <xsl:for-each select="descendant::node()/@title">
                                <xsl:value-of select="."/>
                                <xsl:if test="not(ends-with( current(), '.')) and not(ends-with(., '?')) and not(ends-with(., '!')) and not(ends-with(., ':'))">
                                    <xsl:text>.</xsl:text>
                                </xsl:if>
                                <xsl:text> </xsl:text>
                            </xsl:for-each>
                        </xsl:when>
                        <xsl:when test="name()='lesson' or name()='unit'">
                            <xsl:if test="elml:entry/@title">
                                <xsl:value-of select="elml:entry/@title"/>
                                <xsl:text>. </xsl:text>
                            </xsl:if>
                            <xsl:for-each select="elml:entry/descendant::node()/@title">
                                <xsl:value-of select="."/>
                                <xsl:if test="not(ends-with( current(), '.')) and not(ends-with(., '?')) and not(ends-with(., '!')) and not(ends-with(., ':'))">
                                    <xsl:text>.</xsl:text>
                                </xsl:if>
                                <xsl:text> </xsl:text>
                            </xsl:for-each>
                        </xsl:when>
                        <xsl:when test="name()='furtherReading'">
                            <xsl:text>A list of recommended writings for further reading on this topic. Includes: </xsl:text>
                            <xsl:for-each-group select="elml:resItem/@bibIDRef" group-by="/elml:lesson/elml:bibliography/*[@bibID=current()]/name()">
                                <xsl:sort select="/elml:lesson/elml:bibliography/*[@bibID=current()]/name()" order="ascending" lang="{$lang}"/>
                                <xsl:call-template name="elml:name_biblio">
                                    <xsl:with-param name="itemname" select="concat(name(/elml:lesson/elml:bibliography/*[@bibID=current()]),'Meta')"/>
                                </xsl:call-template>
                                <xsl:choose>
                                    <xsl:when test="not(position()=last())">
                                        <xsl:text>, </xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>.</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:for-each-group>
                        </xsl:when>
                        <xsl:when test="name()='bibliography'">
                            <xsl:text>A comprehensive list of writings cited within this lesson. Includes: </xsl:text>
                            <xsl:for-each-group select="node()" group-by="name()">
                                <xsl:sort select="name()" order="ascending" lang="{$lang}"/>
                                <xsl:call-template name="elml:name_biblio">
                                    <xsl:with-param name="itemname" select="concat(name(),'Meta')"/>
                                </xsl:call-template>
                                <xsl:choose>
                                    <xsl:when test="not(position()=last())">
                                        <xsl:text>, </xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>.</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:for-each-group>
                        </xsl:when>
                        <xsl:when test="name()='glossary'">
                            <xsl:text>List of this lessons relevant terms with its definitions and further explanations. </xsl:text>
                        </xsl:when>
                        <xsl:when test="name()='index'">
                            <xsl:text>List of words and associated pointers - either links or page numbers (in printed version) - to where those words can be found in the lesson. Not to be confused with the glossary. </xsl:text>
                        </xsl:when>
                    </xsl:choose>
                </xsl:attribute>
            </meta>
            <meta name="copyright">
                <xsl:attribute name="content">
                    <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyright"/>
                    <xsl:if test="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL">
                        <xsl:text> (see </xsl:text>
                        <xsl:value-of select="$server"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="/elml:lesson/@label"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="$lang"/>
                        <xsl:text>/html/</xsl:text>
                        <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL"/>
                        <xsl:text>)</xsl:text>
                    </xsl:if>
                </xsl:attribute>
            </meta>
            <meta name="author">
                <xsl:attribute name="content">
                    <xsl:for-each select="/elml:lesson/elml:metadata/elml:lessonInfo/elml:lifecycle/elml:contribute/elml:person">
                        <xsl:value-of select="@name"/> (<xsl:value-of select="@responsible"/>) <xsl:if test="not(position()=last())">, </xsl:if>
                    </xsl:for-each>
                </xsl:attribute>
            </meta>
            <meta name="keywords">
                <xsl:attribute name="content">
                    <xsl:value-of select="/elml:lesson/@title"/>, <xsl:for-each select="/elml:lesson/elml:metadata/elml:keywords/elml:keywordItem">
                        <xsl:value-of select="."/>
                        <xsl:if test="not(position()=last())">, </xsl:if>
                    </xsl:for-each>
                    <xsl:for-each select="/elml:lesson/elml:glossary/elml:definition">
                        <xsl:value-of select="@term"/>, </xsl:for-each>
                </xsl:attribute>
            </meta>
            <title>
                <xsl:if test="not(@title)">
                    <xsl:value-of select="/elml:lesson/@title"/>
                    <xsl:text>: </xsl:text>
                </xsl:if>
                <xsl:call-template name="elml:Kapitel"/>
            </title>
            <xsl:if test="descendant::elml:selfCheck">
                <xsl:call-template name="elml:LayoutSelfCheckCSS"/>
                <xsl:call-template name="elml:LayoutSelfCheckScript"/>
            </xsl:if>
            <link href="rss.xml" rel="alternate" type="application/rss+xml" title="RSS Feed"/>
            <link href="atom.xml" rel="alternate" type="application/atom+xml" title="Atom Feed"/>
            <xsl:choose>
                <xsl:when test="not($layout='none')">
                    <link href="../../../_templates/{$layout}/elml.css" type="text/css" rel="stylesheet" media="screen"/>
                    <link href="../../../_templates/{$layout}/elml_print.css" type="text/css" rel="stylesheet" media="print,handheld"/>
                    <script src="../../../_templates/{$layout}/elml.js" type="text/javascript"><![CDATA[ ]]></script>
                </xsl:when>
                <xsl:when test="$css_framework='yaml'">
                    <link href="http://www.yaml.de/fileadmin/css/layout_2col_left.css" type="text/css" rel="stylesheet" media="screen"/>
                    <xsl:call-template name="elml:LayoutHeadDefaultCSS"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="elml:LayoutHeadDefaultCSS"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="$css_framework='yaml'">
                <xsl:text disable-output-escaping="yes"> <![CDATA[
                    <!--[if lte IE 7]>
                    <link href="../../../_templates]]></xsl:text>
                <xsl:text disable-output-escaping="yes"><![CDATA[/yaml/patches/patch_layout_draft.css" rel="stylesheet" type="text/css" />
                        <![endif]--> 
                        ]]> </xsl:text>
            </xsl:if>
            <xsl:if test="$lightwindow='yes'">
                <script type="text/javascript" src="../../../_templates/{$layout}/lightwindow/javascript/prototype.js" id="lwloader_prototype_js"><![CDATA[ ]]></script>
                <script type="text/javascript" src="../../../_templates/{$layout}/lightwindow/javascript/effects.js" id="lwloader_effects_js"><![CDATA[ ]]></script>
                <script type="text/javascript" src="../../../_templates/{$layout}/lightwindow/javascript/lightwindow_loader.js" id="lwloader"><![CDATA[ ]]></script>
            </xsl:if>
            <xsl:if test="$manifest_type='scorm'">
                <script type="text/javascript" language="JavaScript1.2" src="scorm_generic.js"/>
                <script type="text/javascript">
                    scormCommunication();</script>
            </xsl:if>
        </head>
    </xsl:template>
    <xsl:template name="elml:LayoutBody">
        <xsl:param name="filename">
            <xsl:call-template name="elml:Label_param"/>
        </xsl:param>
        <body>
            <xsl:if test="$manifest_type='scorm'">
                <xsl:attribute name="onunload">
                    <xsl:value-of>finish()</xsl:value-of>
                </xsl:attribute>
            </xsl:if>
            <div id="b_page_margins">
                <div id="b_page_wrapper">
                    <div id="b_page">
                        <a name="b_top" id="b_top"/>
                        <div id="b_header">
                            <span class="b_skip">Access keys for a quick navigation</span>
                            <a accesskey="0" class="b_skip" href="#b_top">0: Top of page</a>
                            <a accesskey="n" class="b_skip" href="#b_nav">n: Main navigation</a>
                            <span class="b_skip">Direct links to main chapters: h: home; 1; about OLAT; 2: download; 3: development</span>
                            <span class="b_skip">Search field: s</span>
                            <a accesskey="o" class="b_skip" href="#b_topnav">o: Top navigation</a>
                            <a accesskey="m" class="b_skip" href="#b_col1">m: Menu</a>
                            <a accesskey="c" class="b_skip" href="#b_col3">c: Content area</a>
                            <span class="b_skip">b: One step back (if available)</span>
                            <div id="b_topnav">
                                <a name="b_topnav"/>
                                <ul>
                                    <li id="o_topnav_search">
                                        <form action="http://www.olat.org/website/en/html/website_search.html" id="cse-search-box">
                                            <label style="display:none" for="o_fulltextsearch">Search</label>
                                            <input type="hidden" name="cx" value="002842011721033055610:yl3outuoqti"/>
                                            <input type="hidden" name="cof" value="FORID:9"/>
                                            <input id="o_fulltextsearch" accesskey="s" type="text" name="q" value="Search" maxlength="50" onclick="this.value='';"/>
                                            <button type="submit" name="sa" title="Search within OLAT"/>
                                        </form>
                                        <script type="text/javascript" src="http://www.google.com/coop/cse/brand?form=cse-search-box&amp;lang=en"/>
                                    </li>
                                    <li id="o_topnav_help">
                                        <a href="http://www.olat.org/website/en/html/website_contact.html">Help</a>
                                    </li>
                                    <li id="o_topnav_printview">
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:text>../text/</xsl:text>
                                                <xsl:value-of select="/elml:lesson/@label"/>
                                                <xsl:text>.pdf</xsl:text>
                                            </xsl:attribute>
                                            <xsl:value-of select="$name_print"/>
                                        </a>
                                    </li>
                                    <li id="o_topnav_login">
                                        <a href="http://demo.olat.org" target="_blank">Demo-Login</a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <xsl:call-template name="elml:navigation_olat_main"/>
<!-- Here the navigation on the front page gets shielded -->
<!-- old version <div id="b_main" class="b_hidecol2"> -->
						<xsl:element name="div">
							<xsl:choose>
								<xsl:when test="parent::elml:lesson">
									<xsl:attribute name="class">
										<xsl:value-of>b_hidecol2</xsl:value-of>
									</xsl:attribute>
								</xsl:when>
								<xsl:when test="parent::elml:unit">
									<xsl:attribute name="class">
										<xsl:value-of>b_hidecol2</xsl:value-of>
									</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:value-of>b_hideboth</xsl:value-of>
									</xsl:attribute>			
								</xsl:otherwise>
							</xsl:choose>
							<xsl:attribute name="id">
								<xsl:value-of>b_main</xsl:value-of>
							</xsl:attribute>			
                            <div id="b_col1" style="width: 14em;">
                                <div id="b_col1_content" class="b_clearfix">
                                    <a name="b_col1"/>
                                    <div class="b_floatbox">
                                        <div class="b_tree">
                                            <ul class="b_tree_l0">
                                                <li>
                                                    <strong>
                                                        <a class="b_tree_selected b_tree_l0">
                                                            <xsl:attribute name="href">
                                                                <xsl:choose>
                                                                    <xsl:when test="name()='unit'">
                                                                        <xsl:text>unit_</xsl:text>
                                                                        <xsl:value-of select="@label"/>
                                                                    </xsl:when>
                                                                    <xsl:when test="parent::elml:unit">
                                                                        <xsl:text>unit_</xsl:text>
                                                                        <xsl:value-of select="parent::elml:unit/@label"/>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>
                                                                        <xsl:text>index</xsl:text>
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                                <xsl:value-of select="$filename_suffix"/>
                                                            </xsl:attribute>
                                                            <xsl:choose>
                                                                <xsl:when test="parent::elml:unit/@navTitle">
                                                                    <xsl:value-of select="parent::elml:unit/@navTitle"/>
                                                                </xsl:when>
                                                                <xsl:when test="parent::elml:unit/@title">
                                                                    <xsl:value-of select="parent::elml:unit/@title"/>
                                                                </xsl:when>
                                                                <xsl:when test="name()='lesson' or name()='unit'">
                                                                    <xsl:call-template name="elml:Kapitel">
                                                                        <xsl:with-param name="isnavigation">yes</xsl:with-param>
                                                                    </xsl:call-template>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:choose>
                                                                        <xsl:when test="/elml:lesson/@navTitle">
                                                                            <xsl:value-of select="/elml:lesson/@navTitle"/>
                                                                        </xsl:when>
                                                                        <xsl:otherwise>
                                                                            <xsl:value-of select="/elml:lesson/@title"/>
                                                                        </xsl:otherwise>
                                                                    </xsl:choose>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </a>
                                                    </strong>
                                                    <ul class=" b_tree_l1">
                                                        <xsl:choose>
                                                            <xsl:when test="name()='unit'">
                                                                <xsl:apply-templates select="elml:learningObject | elml:selfAssessment | elml:summary | elml:furtherReading" mode="navigation_olat_col1">
                                                                    <xsl:with-param name="filename" select="$filename"/>
                                                                </xsl:apply-templates>
                                                            </xsl:when>
                                                            <xsl:when test="parent::elml:unit">
                                                                <xsl:apply-templates select="parent::elml:unit/elml:learningObject | parent::elml:unit/elml:selfAssessment | parent::elml:unit/elml:summary | parent::elml:unit/elml:furtherReading" mode="navigation_olat_col1">
                                                                    <xsl:with-param name="filename" select="$filename"/>
                                                                </xsl:apply-templates>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <xsl:apply-templates select="/elml:lesson/elml:selfAssessment | /elml:lesson/elml:summary | /elml:lesson/elml:furtherReading | /elml:lesson/elml:glossary | /elml:lesson/elml:listOfFigures | /elml:lesson/elml:listOfTables | /elml:lesson/elml:index | /elml:lesson/elml:bibliography | /elml:lesson/elml:metadata" mode="navigation_olat_col1">
                                                                    <xsl:with-param name="filename" select="$filename"/>
                                                                </xsl:apply-templates>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                    </ul>
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div id="b_col2" style="width: 12em;">
                                <div id="b_col2_content" class="b_clearfix">
                                    <a name="b_col2"/> THIRDROW </div>
                            </div>
                            <div id="b_col3" style="margin-left: 14em; margin-right: 12em;">
                                <div id="b_col3_content" class="b_clearfix">
                                    <a id="b_content" name="content"/>
                                    <xsl:if test="not(name()='lesson')">
                                        <img src="../../../_templates/{$layout}/images/olat_logo2_72.png" alt="OLAT Logo" align="right"/>
                                    </xsl:if>
                                    <div id="b_col3_content_inner" class="b_floatscrollbox">
                                        <a name="b_col3"/>
                                        <xsl:call-template name="elml:LayoutBodyContent"/>
                                        <a href="rss.xml" id="rss">
                                            <img src="../../../_templates/{$layout}/file_icons/osx/tiny/rss.png" alt="RSS" align="right"/>
                                        </a>
                                    </div>
                                </div>
                                <div id="b_ie_clearing">&amp;nbsp; </div>
                            </div>
						</xsl:element>
                        <xsl:call-template name="elml:footer"/>
                    </div>
                    <div id="b_border-bottom">
                        <div id="b_edge-lb"/>
                        <div id="b_edge-rb"/>
                    </div>
                </div>
            </div>
            <!-- END olatContentPanel -->
            <div id="b_ajax_busy" class=""/>
            <div id="b_width_1em" style="width:1em; position: absolute; left: -1000px;"/>
            <script type="text/javascript"><![CDATA[ 
				var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
				document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E")); ]]>
            </script>
            <script type="text/javascript"><![CDATA[ 
				var pageTracker = _gat._getTracker("UA-3190454-1");
				pageTracker._initData();
				pageTracker._trackPageview(); ]]>
            </script>
        </body>
    </xsl:template>
    <xsl:template name="elml:feed_rss">
        <xsl:variable name="date">
            <xsl:value-of select="current-dateTime()"/>
        </xsl:variable>
        <xsl:result-document href="{elml:get_pathHTML(base-uri(),/elml:lesson/@label)}rss.xml" format="manifest" exclude-result-prefixes="xs elml">
            <rss version="2.0" xmlns="" xmlns:atom="http://www.w3.org/2005/Atom">
                <channel>
                    <title>
                        <xsl:value-of select="/elml:lesson/@title"/>
                    </title>
                    <link>
                        <xsl:value-of select="$server"/>
                    </link>
                    <atom:link rel="self" type="application/rss+xml">
                        <xsl:attribute name="href">
                            <xsl:value-of select="$server"/>
                            <xsl:text>/</xsl:text>
                            <xsl:value-of select="/elml:lesson/@label"/>
                            <xsl:text>/</xsl:text>
                            <xsl:value-of select="$lang"/>
                            <xsl:text>/html/rss.xml</xsl:text>
                        </xsl:attribute>
                    </atom:link>
                    <description>This is the official RSS-Feed for the open source learning management system OLAT</description>
                    <language>
                        <xsl:value-of select="$lang"/>
                    </language>
                    <copyright>
                        <xsl:text>© </xsl:text>
                        <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyright"/>
                        <xsl:if test="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL">
                            <xsl:text> (see </xsl:text>
                            <xsl:value-of select="$server"/>
                            <xsl:text>/</xsl:text>
                            <xsl:value-of select="/elml:lesson/@label"/>
                            <xsl:text>/</xsl:text>
                            <xsl:value-of select="$lang"/>
                            <xsl:text>/html/</xsl:text>
                            <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL"/>
                            <xsl:text>)</xsl:text>
                        </xsl:if>
                    </copyright>
                    <webMaster>
                        <xsl:value-of select="$contact"/>
                        <xsl:text> (Webmaster)</xsl:text>
                    </webMaster>
                    <docs>http://www.rssboard.org/rss-2-0</docs>
                    <pubDate>
                        <xsl:value-of select="format-dateTime(current-dateTime(), '[FNn,*-3], [D01] [MNn,*-3] [Y] [H01]:[m01]:[s01] +0200', 'en', (), ())"/>
                    </pubDate>
                    <generator>This RSS Feed and also the whole website was created using the eLesson Markup Language (eLML) - see www.elml.ch for more information.</generator>
                    <image>
                        <url>http://www.olat.org/_templates/olat/images/olat_logo2_128.png</url>
                        <title>
                            <xsl:value-of select="/elml:lesson/@title"/>
                        </title>
                        <link>
                            <xsl:value-of select="$server"/>
                        </link>
                    </image>
                    <xsl:for-each select="//*[@cssClass='rss']">
                        <item>
                            <title>
                                <xsl:value-of select="@title"/>
                            </title>
                            <link>
                                <xsl:call-template name="elml:feed_link"/>
                            </link>
                            <category>
                                <xsl:call-template name="elml:feed_category"/>
                            </category>
                            <description>
                                <xsl:value-of select="."/>
                            </description>
                            <guid>
                                <xsl:call-template name="elml:feed_link"/>
                                <xsl:text>#</xsl:text>
                                <xsl:choose>
                                    <xsl:when test="@label">
                                        <xsl:value-of select="@label"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="generate-id()"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </guid>
                            <xsl:if test="/elml:lesson/elml:metadata/elml:lessonInfo/elml:lifecycle/elml:contribute/elml:person">
                                <xsl:for-each select="/elml:lesson/elml:metadata/elml:lessonInfo/elml:lifecycle/elml:contribute/elml:person">
                                    <author>
                                        <xsl:value-of select="@email"/>
                                        <xsl:text> (</xsl:text>
                                        <xsl:value-of select="@name"/>
                                        <xsl:text>)</xsl:text>
                                    </author>
                                </xsl:for-each>
                            </xsl:if>
                            <pubDate>
                                <xsl:choose>
                                    <xsl:when test=" starts-with(.,'(')">
                                        <xsl:value-of select="format-dateTime( dateTime(xs:date(concat( substring(.,8,4),'-', substring(.,5,2),'-', substring(.,2,2))),xs:time('00:00:00')), '[FNn,*-3], [D01] [MNn,*-3] [Y] [H01]:[m01]:[s01] GMT', 'en', (), ())"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="format-dateTime(current-dateTime(), 'Sun, 01 Jan 2006 00:00:00 GMT', 'en', (), ())"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </pubDate>
                        </item>
                    </xsl:for-each>
                </channel>
            </rss>
        </xsl:result-document>
        <xsl:result-document href="{elml:get_pathHTML(base-uri(),/elml:lesson/@label)}iphone.html" format="online">
            <html>
                <head>
                    <title>
                        <xsl:choose>
                            <xsl:when test="/elml:lesson/@navTitle">
                                <xsl:value-of select="/elml:lesson/@navTitle"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="/elml:lesson/@title"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </title>
                    <meta name="viewport" content="width=320; initial-scale=1.0; maximum-scale=1.0; user-scalable=0;"/>
                    <link rel="stylesheet" href="iphone/iphone.css" type="text/css" media="screen"/>
                    <script type="application/x-javascript" src="iphone/iphone.js"> </script>
                    <link rel="apple-touch-icon" href="../../../_templates/{$layout}/images/olat_logo2_72.png"/>
                    <style type="text/css" media="screen">
                        &#xE001;<![CDATA[!-- 
	
                    .multimedia_paragraph_left  /* for multimedia objects that are used as paragraph and have no align or align=left */ { float: none; clear: both; padding: 1em 1em 1em 0; display: block; }
                    .multimedia_paragraph_center  /* for multimedia objects that are used as paragraph and have align=center */ { text-align: center; width: 100%; float: none; clear: both; padding: 1em; display: block; }
                    .multimedia_paragraph_right  /* for multimedia objects that are used as paragraph and have align=right */ { text-align: right; float: none; clear: both; padding: 1em 0 1em 1em; display: block; }
                    .multimedia_inline_left  /* for multimedia objects that are used as inline and have align=left */ { float: left; padding-right: 1em; padding-left: 0; display: inline; }
                    .multimedia_inline_center  /* for multimedia objects that are used as paragraph and have align=center */ { text-align: center; width: 100%; float: left; padding-right: 1em; padding-left: 1em; display: inline; }
                    .multimedia_inline_right  /* for multimedia objects that are used as paragraph and have align=right */ { text-align: right; float: right; padding-right: 0; padding-left: 1em; display: inline; }
                    .b_skip, #b_header, #b_topnav, #b_nav, #b_col1, #b_col2, #b_border-bottom, #b_footer, #b_ie_clearing, #b_ajax_busy, #b_width_1em, #rss {display:none;}
                    .b_hidecol2 #b_col3 {margin-left: 0 ! important; margin-right: 0 ! important; border-left: 0; border-right: 0}
  .b_c50l, .b_c25l, .b_c33l, .b_c38l, .b_c66l, .b_c75l, .b_c62l {float: left; }
  .b_c50r, .b_c25r, .b_c33r, .b_c38r, .b_c66r, .b_c75r, .b_c62r {float: right; margin-left: -5px; }
  .b_c25l, .b_c25r { width: 25% }
  .b_c33l, .b_c33r { width: 33.333% }
  .b_c50l, .b_c50r { width: 50% }
  .b_c66l, .b_c66r { width: 66.666% }
  .b_c75l, .b_c75r { width: 75% }
  .b_c38l, .b_c38r { width: 38.2% }
  .b_c62l, .b_c62r { width: 61.8% }
  .b_subc  { padding: 0 0.5em }
  .b_subcl { padding: 0 1em 0 0 }
  .b_subcr { padding: 0 0 0 1em }
                      .b_subcolumns { width: 100%;overflow:hidden;}
               ]]>
                        --&#xE002;</style>
                </head>
                <body>
                    <div class="toolbar">
                        <h1 id="pageTitle"/>
                        <a id="backButton" class="button" href="#"/>
                    </div>
                    <ul selected="true">
                        <xsl:attribute name="title">
                            <xsl:choose>
                                <xsl:when test="/elml:lesson/@navTitle">
                                    <xsl:value-of select="/elml:lesson/@navTitle"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="/elml:lesson/@title"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:attribute>
                        <xsl:for-each select="//*[@cssClass='rss']">
                            <li>
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:text>#</xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="@label">
                                                <xsl:value-of select="@label"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="generate-id()"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:attribute>
                                    <xsl:value-of select="@title"/>
                                </a>
                            </li>
                        </xsl:for-each>
                    </ul>
                    <xsl:for-each select="//*[@cssClass='rss']">
                        <div class="panel">
                            <xsl:attribute name="title">
                                <xsl:choose>
                                    <xsl:when test="@navTitle">
                                        <xsl:value-of select="@navTitle"/>
                                    </xsl:when>
                                    <xsl:when test="@title">
                                        <xsl:value-of select="@title"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>Full Article</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:attribute>
                            <xsl:attribute name="id">
                                <xsl:choose>
                                    <xsl:when test="@label">
                                        <xsl:value-of select="@label"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="generate-id()"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:attribute>
                            <xsl:apply-templates/>
                        </div>
                    </xsl:for-each>
                </body>
            </html>
        </xsl:result-document>
    </xsl:template>
    <xsl:template name="elml:feed_atom">
        <xsl:result-document href="{elml:get_pathHTML(base-uri(),/elml:lesson/@label)}atom.xml" format="manifest" exclude-result-prefixes="xs elml">
            <feed xmlns="http://www.w3.org/2005/Atom">
                <title>
                    <xsl:value-of select="/elml:lesson/@title"/>
                </title>
                <link href="http://www.olat.org/"/>
                <link rel="self" type="application/rss+xml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="$server"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="/elml:lesson/@label"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="$lang"/>
                        <xsl:text>/html/atom.xml</xsl:text>
                    </xsl:attribute>
                </link>
                <updated>
                    <xsl:value-of select="current-dateTime()"/>
                </updated>
                <xsl:if test="/elml:lesson/elml:metadata/elml:lessonInfo/elml:lifecycle/elml:contribute/elml:person">
                    <xsl:for-each select="/elml:lesson/elml:metadata/elml:lessonInfo/elml:lifecycle/elml:contribute/elml:person">
                        <author>
                            <name>
                                <xsl:value-of select="@name"/>
                            </name>
                            <email>
                                <xsl:value-of select="@email"/>
                            </email>
                        </author>
                    </xsl:for-each>
                </xsl:if>
                <id>
                    <xsl:value-of select="$server"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="/elml:lesson/@label"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$lang"/>
                    <xsl:text>/html/index.html</xsl:text>
                </id>
                <generator uri="http://www.elml.ch"> This RSS Feed and also the whole website was created using the eLesson Markup Language (eLML) - see www.elml.ch for more information. </generator>
                <icon>
                    <xsl:value-of select="$server"/>
                    <xsl:text>/favicon.ico</xsl:text>
                </icon>
                <logo>http://www.olat.org/_templates/olat/images/olat_logo2_128.png</logo>
                <rights>
                    <xsl:text>© </xsl:text>
                    <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyright"/>
                    <xsl:if test="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL">
                        <xsl:text> (see </xsl:text>
                        <xsl:value-of select="$server"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="/elml:lesson/@label"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="$lang"/>
                        <xsl:text>/html/</xsl:text>
                        <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL"/>
                        <xsl:text>)</xsl:text>
                    </xsl:if>
                </rights>
                <subtitle>This is the official RSS-Feed for the open source learning management system OLAT</subtitle>
                <xsl:for-each select="//*[@cssClass='rss']">
                    <entry>
                        <title>
                            <xsl:value-of select="@title"/>
                        </title>
                        <link rel="alternate">
                            <xsl:attribute name="href">
                                <xsl:call-template name="elml:feed_link"/>
                            </xsl:attribute>
                        </link>
                        <content>
                            <xsl:value-of select="."/>
                        </content>
                        <!-- 
						<content type="xhtml" xml:lang="{$lang}">
							<div xmlns="http://www.w3.org/1999/xhtml">
								<xsl:attribute name="xml:base">
									<xsl:value-of select="$server"/>
									<xsl:text>/</xsl:text>
									<xsl:value-of select="/elml:lesson/@label"/>
									<xsl:text>/</xsl:text>
									<xsl:value-of select="$lang"/>
									<xsl:text>/html/</xsl:text>
								</xsl:attribute>
								<xsl:apply-templates/>
							</div>
							</content> -->
                        <category>
                            <xsl:attribute name="term">
                                <xsl:call-template name="elml:feed_category"/>
                            </xsl:attribute>
                        </category>
                        <id>
                            <xsl:call-template name="elml:feed_link"/>
                            <xsl:text>#</xsl:text>
                            <xsl:choose>
                                <xsl:when test="@label">
                                    <xsl:value-of select="@label"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="generate-id()"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </id>
                        <summary>
                            <xsl:value-of select="."/>
                        </summary>
                        <updated>
                            <xsl:choose>
                                <xsl:when test=" starts-with(.,'(')">
                                    <xsl:value-of select="format-dateTime( dateTime(xs:date(concat( substring(.,8,4),'-', substring(.,5,2),'-', substring(.,2,2))),xs:time('00:00:00')), '[Y0001]-[M01]-[D01]T[H01]:[m01]:[s01]+02:00', 'en', (), ())"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="format-dateTime(current-dateTime(), 'Sun, 01 Jan 2006 00:00:00 GMT', 'en', (), ())"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </updated>
                    </entry>
                </xsl:for-each>
            </feed>
        </xsl:result-document>
    </xsl:template>
    <xsl:template name="elml:feed_link">
        <xsl:value-of select="$server"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="/elml:lesson/@label"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="$lang"/>
        <xsl:text>/html/</xsl:text>
        <xsl:choose>
            <xsl:when test="not($pagebreak_level='unit') and not($pagebreak_level='lo')">
                <xsl:text>index</xsl:text>
            </xsl:when>
            <xsl:when test="$pagebreak_level='lo'">
                <xsl:choose>
                    <xsl:when test="ancestor::node()/name()='learningObject'">
                        <xsl:value-of select="ancestor::node()[name()='unit']/@label"/>
                        <xsl:text>_</xsl:text>
                        <xsl:choose>
                            <xsl:when test="ancestor::node()[name()='learningObject']/@label">
                                <xsl:value-of select="ancestor::node()[name()='learningObject']/@label"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>learningObject</xsl:text>
                                <xsl:value-of select="1+count(ancestor::node()[name()='learningObject']/preceding-sibling::node()[name()='learningObject']/name())"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="ancestor::node()/name()='selfAssessment'">
                        <xsl:choose>
                            <xsl:when test="ancestor::node()/name()='unit'">
                                <xsl:value-of select="ancestor::node()[name()='unit']/@label"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="/elml:lesson/@label"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>_</xsl:text>
                        <xsl:choose>
                            <xsl:when test="ancestor::node()[name()='selfAssessment']/@label">
                                <xsl:value-of select="ancestor::node()[name()='selfAssessment']/@label"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>selfAssessment</xsl:text>
                                <xsl:value-of select="1+count(ancestor::node()[name()='selfAssessment']/preceding-sibling::node()[name()='learningObject']/name())+count(ancestor::node()[name()='selfAssessment']/preceding-sibling::node()[name()='selfAssessment']/name())"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="ancestor::node()/name()='summary'">
                        <xsl:choose>
                            <xsl:when test="ancestor::node()/name()='unit'">
                                <xsl:value-of select="ancestor::node()[name()='unit']/@label"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="/elml:lesson/@label"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>_</xsl:text>
                        <xsl:choose>
                            <xsl:when test="ancestor::node()[name()='summary']/@label">
                                <xsl:value-of select="ancestor::node()[name()='summary']/@label"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>summary</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="ancestor::node()/name()='entry'">
                        <xsl:choose>
                            <xsl:when test="ancestor::node()/name()='unit'">
                                <xsl:text>unit_</xsl:text>
                                <xsl:value-of select="ancestor::node()[name()='unit']/@label"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>index</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>index</xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$pagebreak_level='unit'">
                <xsl:choose>
                    <xsl:when test="ancestor::node()[name()='unit'][1]/@label">
                        <xsl:text>unit_</xsl:text>
                        <xsl:value-of select="ancestor::node()[name()='unit'][1]/@label"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>index</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>index</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="$filename_suffix"/>
        <xsl:if test="@label">
            <xsl:text>#</xsl:text>
            <xsl:value-of select="@label"/>
        </xsl:if>
    </xsl:template>
    <xsl:template name="elml:feed_category">
        <xsl:choose>
            <xsl:when test="ancestor::node()[name()='entry']/@navTitle">
                <xsl:value-of select="ancestor::node()[name()='entry']/@navTitle"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='entry']/@title">
                <xsl:value-of select="ancestor::node()[name()='entry']/@title"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='selfAssessment']/@navTitle">
                <xsl:value-of select="ancestor::node()[name()='selfAssessment']/@navTitle"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='selfAssessment']/@title">
                <xsl:value-of select="ancestor::node()[name()='selfAssessment']/@title"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='summary']/@navTitle">
                <xsl:value-of select="ancestor::node()[name()='summary']/@navTitle"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='summary']/@title">
                <xsl:value-of select="ancestor::node()[name()='summary']/@title"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='learningObject']/@navTitle">
                <xsl:value-of select="ancestor::node()[name()='learningObject']/@navTitle"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='learningObject']/@title">
                <xsl:value-of select="ancestor::node()[name()='learningObject']/@title"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='unit']/@navTitle">
                <xsl:value-of select="ancestor::node()[name()='unit']/@navTitle"/>
            </xsl:when>
            <xsl:when test="ancestor::node()[name()='unit']/@title">
                <xsl:value-of select="ancestor::node()[name()='unit']/@title"/>
            </xsl:when>
            <xsl:when test="/elml:lesson/@navTitle">
                <xsl:value-of select="/elml:lesson/@navTitle"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="/elml:lesson/@title"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Use YAML subcolums for eLML columns -->
    <xsl:template match="elml:column">
        <!--Template that matches the "column" paragraph type.-->
        <xsl:param name="columnleftwidth">
            <xsl:choose>
                <xsl:when test="elml:columnMiddle">
                    <xsl:text>33</xsl:text>
                </xsl:when>
                <xsl:when test="*/@units='percent'">
                    <xsl:choose>
                        <xsl:when test="elml:columnLeft/@width &lt; '29' or elml:columnRight/@width &gt; '70'">
                            <xsl:text>25</xsl:text>
                        </xsl:when>
                        <xsl:when test="elml:columnLeft/@width &lt; '35' or elml:columnRight/@width &gt; '64'">
                            <xsl:text>33</xsl:text>
                        </xsl:when>
                        <xsl:when test="elml:columnLeft/@width &lt; '42' or elml:columnRight/@width &gt; '58'">
                            <xsl:text>38</xsl:text>
                        </xsl:when>
                        <xsl:when test="elml:columnLeft/@width &lt; '58' or elml:columnRight/@width &gt; '42'">
                            <xsl:text>50</xsl:text>
                        </xsl:when>
                        <xsl:when test="elml:columnLeft/@width &lt; '64' or elml:columnRight/@width &gt; '35'">
                            <xsl:text>62</xsl:text>
                        </xsl:when>
                        <xsl:when test="elml:columnLeft/@width &lt; '70' or elml:columnRight/@width &gt; '29'">
                            <xsl:text>66</xsl:text>
                        </xsl:when>
                        <xsl:when test="elml:columnLeft/@width &gt; '69' or elml:columnRight/@width &lt; '30'">
                            <xsl:text>75</xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>50</xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>50</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:param>
        <div>
            <xsl:call-template name="elml:Label"/>
            <xsl:attribute name="class">
                <xsl:text>b_subcolumns </xsl:text>
                <xsl:choose>
                    <xsl:when test="@cssClass">
                        <xsl:value-of select="@cssClass"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="name()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:choose>
                <xsl:when test="elml:columnRight/@units='pixels' and elml:columnRight/@width and not(elml:columnMiddle)">
                    <xsl:apply-templates select="elml:columnRight" mode="yaml">
                        <xsl:with-param name="columnleftwidth" select="$columnleftwidth"/>
                    </xsl:apply-templates>
                    <xsl:apply-templates select="elml:columnLeft" mode="yaml">
                        <xsl:with-param name="columnleftwidth" select="$columnleftwidth"/>
                    </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates mode="yaml">
                        <xsl:with-param name="columnleftwidth" select="$columnleftwidth"/>
                    </xsl:apply-templates>
                </xsl:otherwise>
            </xsl:choose>
        </div>
    </xsl:template>
    <xsl:template match="elml:columnLeft" mode="yaml">
        <xsl:param name="columnleftwidth"/>
        <div>
            <xsl:attribute name="class">
                <xsl:text>b_c</xsl:text>
                <xsl:value-of select="$columnleftwidth"/>
                <xsl:text>l</xsl:text>
            </xsl:attribute>
            <xsl:if test="../elml:columnRight/@units='pixels' and ../elml:columnRight/@width and not(../elml:columnMiddle)">
                <xsl:attribute name="style">
                    <xsl:text>width:auto; float:none; margin-right: </xsl:text>
                    <xsl:value-of select="../elml:columnRight/@width"/>
                    <xsl:text>px;</xsl:text>
                </xsl:attribute>
            </xsl:if>
            <div>
                <xsl:attribute name="class">
                    <xsl:text>b_subcl </xsl:text>
                    <xsl:choose>
                        <xsl:when test="@cssClass">
                            <xsl:value-of select="@cssClass"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="name()"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:choose>
                        <xsl:when test="@align='right'">
                            <xsl:text> b_float_right</xsl:text>
                        </xsl:when>
                        <xsl:when test="@align='center'">
                            <xsl:text> b_center</xsl:text>
                        </xsl:when>
                    </xsl:choose>
                </xsl:attribute>
                <xsl:apply-templates/>
            </div>
        </div>
    </xsl:template>
    <xsl:template match="elml:columnMiddle" mode="yaml">
        <xsl:param name="columnleftwidth"/>
        <div class="b_c33l">
            <div>
                <xsl:attribute name="class">
                    <xsl:text>b_subc </xsl:text>
                    <xsl:choose>
                        <xsl:when test="@cssClass">
                            <xsl:value-of select="@cssClass"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="name()"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:choose>
                        <xsl:when test="@align='right'">
                            <xsl:text> b_float_right</xsl:text>
                        </xsl:when>
                        <xsl:when test="@align='center'">
                            <xsl:text> b_center</xsl:text>
                        </xsl:when>
                    </xsl:choose>
                </xsl:attribute>
                <xsl:apply-templates/>
            </div>
        </div>
    </xsl:template>
    <xsl:template match="elml:columnRight" mode="yaml">
        <xsl:param name="columnleftwidth"/>
        <div>
            <xsl:attribute name="class">
                <xsl:text>b_c</xsl:text>
                <xsl:choose>
                    <xsl:when test="$columnleftwidth='75'">
                        <xsl:text>25</xsl:text>
                    </xsl:when>
                    <xsl:when test="$columnleftwidth='66' or ../elml:columnMiddle">
                        <xsl:text>33</xsl:text>
                    </xsl:when>
                    <xsl:when test="$columnleftwidth='62'">
                        <xsl:text>38</xsl:text>
                    </xsl:when>
                    <xsl:when test="$columnleftwidth='38'">
                        <xsl:text>62</xsl:text>
                    </xsl:when>
                    <xsl:when test="$columnleftwidth='33'">
                        <xsl:text>66</xsl:text>
                    </xsl:when>
                    <xsl:when test="$columnleftwidth='25'">
                        <xsl:text>75</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>50</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text>r</xsl:text>
            </xsl:attribute>
            <xsl:if test="@units='pixels' and @width and not(../elml:columnMiddle)">
                <xsl:attribute name="style">
                    <xsl:text>width: </xsl:text>
                    <xsl:value-of select="../elml:columnRight/@width"/>
                    <xsl:text>px;</xsl:text>
                </xsl:attribute>
            </xsl:if>
            <div>
                <xsl:attribute name="class">
                    <xsl:text>b_subcr </xsl:text>
                    <xsl:choose>
                        <xsl:when test="@cssClass">
                            <xsl:value-of select="@cssClass"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="name()"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:choose>
                        <xsl:when test="@align='right'">
                            <xsl:text> b_float_right</xsl:text>
                        </xsl:when>
                        <xsl:when test="@align='center'">
                            <xsl:text> b_center</xsl:text>
                        </xsl:when>
                    </xsl:choose>
                </xsl:attribute>
                <xsl:apply-templates/>
            </div>
        </div>
    </xsl:template>
    <!-- ***** OLAT Navigation left column *****-->
    <xsl:template match="elml:learningObject | elml:selfAssessment | elml:summary | elml:furtherReading | elml:glossary | elml:listOfFigures | elml:listOfTables | elml:index | elml:bibliography | elml:metadata" mode="navigation_olat_col1">
        <xsl:param name="filename"/>
        <xsl:param name="filenameactual">
            <xsl:call-template name="elml:Label_param"/>
        </xsl:param>
        <xsl:param name="display">
            <xsl:call-template name="elml:display"/>
        </xsl:param>
        <xsl:if test="$display='yes'">
            <li>
                <a class=" b_tree_l1">
                    <xsl:attribute name="href">
                        <xsl:call-template name="elml:Label_param_withfilename"/>
                    </xsl:attribute>
                    <xsl:choose>
                        <xsl:when test="$filename = $filenameactual">
                            <xsl:attribute name="class">
                                <xsl:text>b_tree_selected  b_tree_l1</xsl:text>
                            </xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:attribute name="class">
                                <xsl:text>b_tree_l1</xsl:text>
                            </xsl:attribute>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:call-template name="elml:Kapitel">
                        <xsl:with-param name="isnavigation">yes</xsl:with-param>
                    </xsl:call-template>
                </a>
            </li>
        </xsl:if>
    </xsl:template>
    <!-- ***** OLAT Navigation tabs *****-->
    <xsl:template name="elml:navigation_olat_main">
        <xsl:param name="filename">
            <xsl:call-template name="elml:Label_param"/>
        </xsl:param>
        <xsl:param name="currentunit">
            <xsl:choose>
                <xsl:when test="parent::elml:unit/@label">
                    <xsl:value-of select="parent::elml:unit/@label"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>none</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:param>
        <div id="b_nav">
            <a name="b_nav"/>
            <div id="b_nav_main">
                <ul>
                    <xsl:apply-templates select="/elml:lesson" mode="navigation_olat_main">
                        <xsl:with-param name="filename" select="$filename"/>
                        <xsl:with-param name="currentunit" select="$currentunit"/>
                    </xsl:apply-templates>
                </ul>
            </div>
        </div>
    </xsl:template>
    <xsl:template match="elml:lesson" mode="navigation_olat_main">
        <xsl:param name="filename"/>
        <xsl:param name="currentunit"/>
        <li>
            <xsl:attribute name="class">
                <xsl:text>b_nav_site </xsl:text>
                <xsl:if test="($filename = 'index.html') or ($filename = 'index.xml') or contains($filename,concat(/elml:lesson/@label,'_'))">
                    <xsl:text>b_nav_active</xsl:text>
                </xsl:if>
                <xsl:text> o_site_home</xsl:text>
            </xsl:attribute>
            <div>
                <a accesskey="h" href="index.html"> Home</a>
            </div>
        </li>
        <xsl:apply-templates select="elml:unit" mode="navigation_olat_main">
            <xsl:with-param name="filename" select="$filename"/>
            <xsl:with-param name="currentunit" select="$currentunit"/>
        </xsl:apply-templates>
        <li id="b_nav_spacer"/>
    </xsl:template>
    <xsl:template match="elml:unit" mode="navigation_olat_main">
        <xsl:param name="filename"/>
        <xsl:param name="currentunit"/>
        <xsl:param name="filenameactual">
            <xsl:call-template name="elml:Label_param"/>
        </xsl:param>
        <xsl:param name="display">
            <xsl:call-template name="elml:display"/>
        </xsl:param>
        <xsl:if test="$display='yes'">
            <li>
                <xsl:attribute name="class">
                    <xsl:text>b_nav_site </xsl:text>
                    <xsl:if test="($filename = $filenameactual) or contains($filenameactual,$currentunit) or $filename = concat('unit_',parent::elml:unit/@label,$filename_suffix) ">
                        <xsl:text>b_nav_active</xsl:text>
                    </xsl:if>
                    <xsl:text> o_site_</xsl:text>
                    <xsl:value-of select="@label"/>
                </xsl:attribute>
                <div>
                    <a>
                        <xsl:attribute name="href">
                            <xsl:call-template name="elml:Label_param_withfilename"/>
                        </xsl:attribute>
                        <xsl:attribute name="accesskey">
                            <xsl:value-of select="position()"/>
                        </xsl:attribute>
                        <xsl:call-template name="elml:Kapitel">
                            <xsl:with-param name="isnavigation">yes</xsl:with-param>
                        </xsl:call-template>
                        <xsl:if test="contains($filenameactual, 'unit_') and contains($optional_units, substring-after(substring-before($filenameactual, $filename_suffix), 'unit_'))">
                            <xsl:value-of select="$name_optionalunits_symbol"/>
                        </xsl:if>
                    </a>
                </div>
            </li>
        </xsl:if>
    </xsl:template>
    <xsl:template name="elml:CSS_Class">
        <xsl:attribute name="class">
            <xsl:choose>
                <xsl:when test="@role='tutor'">
                    <xsl:value-of select="@role"/>
                </xsl:when>
                <xsl:when test="@cssClass">
                    <xsl:value-of select="@cssClass"/>
                </xsl:when>
                <xsl:when test="@icon='act' or @icon='important' or @icon='look' or @icon='question' or @icon='remark' or @icon='info'">
                    <xsl:value-of select="name()"/>
                    <xsl:text>_</xsl:text>
                    <xsl:value-of select="@icon"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="name()"/>
                    <!-- alternating rows -->
                    <xsl:if test="(position() mod 2 != 0) and (name()='tablerow' or name()='lObjective' or name()='item')">
                        <xsl:text>Alt</xsl:text>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
    </xsl:template>
    <!-- ***** OLAT Footer *****-->
    <xsl:template name="elml:footer">
        <div id="b_footer" class="b_clearfix">
            <div class="b_floatbox">
                <a id="b_toplink" href="#b_top" accesskey="0" title="Go to the top of the page">Go to top</a>
                <div id="b_footer_user">
                    <p><a>
                            <xsl:attribute name="href">
                                <xsl:choose>
                                    <xsl:when test="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL">
                                        <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyrightURL"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="$server"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:attribute>
                            <xsl:text disable-output-escaping="no"> ©</xsl:text>
                            <xsl:value-of select="/elml:lesson/elml:metadata/elml:rights/elml:copyright"/>
                        </a> | Updated: <xsl:value-of select="day-from-date(current-date())"/>
                        <xsl:text>.</xsl:text>
                        <xsl:value-of select="month-from-date(current-date())"/>
                        <xsl:text>.</xsl:text>
                        <xsl:value-of select="year-from-date(current-date())"/> | Created using <a href="http://www.elml.ch/" target="_blank">eLML</a>
                        <xsl:if test="not($bugtracker='')"> | <a target="_blank">
                                <xsl:attribute name="href">
                                    <xsl:value-of select="$bugtracker"/>
                                </xsl:attribute>
                                <xsl:value-of select="$name_bugtracker"/>
                            </a>
                        </xsl:if> | <a>
                            <xsl:attribute name="href">
                                <xsl:text>mailto:</xsl:text>
                                <xsl:value-of select="$contact"/>
                            </xsl:attribute>
                            <xsl:value-of select="$name_contact"/>
                        </a>
                    </p>
                </div>
                <div id="b_footer_version">
                    <script type="text/javascript" src="http://www.ohloh.net/p/16931/widgets/project_users_logo"/>
                </div>
                <div id="b_footer_powered">
                    <a href="http://www.uzh.ch" target="_blank" title="University of Zurich">
                        <img border="0" src="../../../_templates/{$layout}/images/powered_by_uzh.png" alt="University of Zurich"/>
                    </a>
                </div>
            </div>
        </div>
    </xsl:template>
</xsl:stylesheet>
