<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:elml="http://www.elml.ch" version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2004/07/xpath-functions" xmlns:xdt="http://www.w3.org/2004/07/xpath-datatypes" xmlns:fox="http://xml.apache.org/fop/extensions">
    <xsl:import href="../../../../core/presentation/print/elml.xsl"/>
    <!-- ***** Parameter definitions  *****-->
    <!--The name of this layout (=folder name of template folder!) -->
    <xsl:param name="layout" select="'olat'"/>
    <xsl:param name="role" select="'tutor'"/>
    <xsl:param name="pagebreak_level" select="'lo'"/>
    <xsl:param name="contact" select="'info@olat.org'"/>
    <xsl:param name="fontsize" select="'11pt'"/>
    <xsl:param name="chapter_numeration" select="'no'"/>
    <xsl:param name="shortmanual">
        <xsl:choose>
            <xsl:when test="$lang='de'">
                <xsl:text>OLAT 6.3 Kurzanleitung</xsl:text>
            </xsl:when>
            <xsl:when test="$lang='fr'">
                <xsl:text>OLAT 6.3 petit guide</xsl:text>
            </xsl:when>
            <xsl:when test="$lang='it'">
                <xsl:text>OLAT 6.3 istruzioni brevi</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>OLAT 6.3 Quick Guide</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    <!-- ***** Template definitions  ***** -->
    <!-- Das template für elml:learningObject aus dem core-file wird hiermit überschrieben -->
    <xsl:template match="elml:learningObject">
        <xsl:if test="starts-with(@label, 'short')">
            <fo:block line-height="24pt" font-size="20pt" font-weight="bold" space-after="{$lineheight}*0.4" keep-with-next.within-page="always" text-align="left" span="all" break-before="page" color="#4B4670">
                <xsl:call-template name="elml:Label"/>
                <xsl:call-template name="elml:Kapitel"/>
            </fo:block>
            <xsl:apply-templates/>
        </xsl:if>
    </xsl:template>
    <xsl:template match="elml:tableheading">
        <fo:table-cell padding="3pt" background-color="#7C7997" font-weight="bold" border-style="solid" border-width="0.5pt" border-color="black" border-collapse="collapse">
            <xsl:if test="@colspan">
                <xsl:attribute name="number-columns-spanned">
                    <xsl:value-of select="@colspan"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@rowspan">
                <xsl:attribute name="number-rows-spanned">
                    <xsl:value-of select="@rowspan"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:call-template name="elml:WidthHeight"/>
            <xsl:call-template name="elml:Alignment"/>
            <fo:block>
                <xsl:call-template name="elml:Alignment"/>
                <xsl:apply-templates/>
            </fo:block>
        </fo:table-cell>
    </xsl:template>
    <!-- wird für die Ausblendung des Stichwortverzeichnisses überschrieben-->
    <xsl:template match="elml:index"/>
    <!-- wird für die Ausblendung des Stichwortverzeichnisses überschrieben-->
    <xsl:template match="elml:index" mode="generate_index"> </xsl:template>
    <!-- wird für die Ausblendung des Inhaltsverzeichnisses überschrieben-->
    <xsl:template match="/">
        <fo:root font-family="Frutiger, Frutiger-Roman, Verdana, Arial, Helvetica, sans-serif">
            <xsl:if test="$hyphenation='yes'">
                <xsl:attribute name="hyphenate" select="'true'"/>
                <xsl:attribute name="language" select="$lang"/>
            </xsl:if>
            <fo:layout-master-set>
                <fo:simple-page-master master-name="default-page" page-height="{$pageheight}" page-width="{$pagewidth}" margin-top="15mm" margin-bottom="15mm" margin-left="20mm" margin-right="20mm">
                    <fo:region-body margin-top="16mm" margin-bottom="15mm"/>
                    <fo:region-before extent="10mm"/>
                    <fo:region-after extent="10mm"/>
                </fo:simple-page-master>
            </fo:layout-master-set>
            <fo:page-sequence master-reference="default-page" initial-page-number="1" format="1">
                <fo:static-content flow-name="xsl-region-before">
                    <fo:block font-size="8pt" font-weight="bold" color="black" border-after-style="solid" text-align-last="justify">
                        <xsl:value-of select="$shortmanual"/>
                        <fo:leader leader-pattern="space"/>
                        <fo:external-graphic scaling="uniform" id="olat_logo" width="1cm">
                            <xsl:if test="not($fop_version='0.2')">
                                <xsl:attribute name="content-width">
                                    <xsl:text>scale-to-fit</xsl:text>
                                </xsl:attribute>
                            </xsl:if>
                            <xsl:attribute name="src">
                                <xsl:value-of select="$pathRoot"/>
                                <xsl:text>/_templates/</xsl:text>
                                <xsl:value-of select="$layout"/>
                                <xsl:text>/images/olat_logo2_720.png</xsl:text>
                            </xsl:attribute>
                        </fo:external-graphic>
                    </fo:block>
                </fo:static-content>
                <fo:static-content flow-name="xsl-region-after" display-align="after">
                    <fo:block font-size="8pt" font-weight="bold" color="black" border-before-style="solid" text-align-last="justify">
                        <xsl:value-of select="$server"/>
                        <xsl:text> - </xsl:text>
                        <xsl:value-of select="$name_printed"/>
                        <xsl:value-of select="day-from-date(current-date())"/>
                        <xsl:text>.</xsl:text>
                        <xsl:value-of select="month-from-date(current-date())"/>
                        <xsl:text>.</xsl:text>
                        <xsl:value-of select="year-from-date(current-date())"/>
                    </fo:block>
                </fo:static-content>
                <fo:static-content flow-name="xsl-footnote-separator">
                    <fo:block>
                        <fo:leader leader-pattern="rule" leader-length="30%" rule-thickness="0.5pt" rule-style="solid" color="black" display-align="before"/>
                    </fo:block>
                </fo:static-content>
                <fo:flow flow-name="xsl-region-body" text-align="justify" font-size="{$fontsize}" line-height="{$lineheight}" orphans="3" widows="3">
                    <xsl:apply-templates/>
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>
    <!-- nicht jede Unit darf erscheinen, nur jene Unit welche zugelassene LO's hält -->
    <xsl:template match="elml:unit">
        <xsl:param name="display">
            <xsl:call-template name="elml:display"/>
        </xsl:param>
        <!-- Test ob in den Kindeskinder-Knoten ein LO ist welches zugelassen wird -->
        <xsl:if test="descendant::elml:learningObject[starts-with(@label, 'short')]">
            <xsl:if test="$display='yes'">
                <!-- <xsl:call-template name="elml:generate_Title"/> -->
                <xsl:if test="name(.)='unit' and contains($optional_units, @label)">
                    <fo:block border-style="solid" border-color="red" border-width="0.5pt" background-color="lightgrey" padding="3pt" margin="5pt">
                        <xsl:value-of select="$name_optionalunits_text"/>
                    </fo:block>
                </xsl:if>
                <xsl:apply-templates/>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    <xsl:template match="elml:entry"/>
    <xsl:template name="elml:Kapitel_Title">
        <xsl:param name="isnavigation"/>
        <xsl:choose>
            <xsl:when test="(($isnavigation='yes') or ($isnavigation='path_full')) and (@navTitle)">
                <xsl:value-of select="@navTitle"/>
            </xsl:when>
            <xsl:when test="name()='entry' and $isnavigation='yes'">
                <xsl:value-of select="$name_entry"/>
            </xsl:when>
            <xsl:when test="@title">
                <xsl:value-of select="@title"/>
            </xsl:when>
            <xsl:when test="name()='glossary'">
                <xsl:value-of select="$name_glossary"/>
            </xsl:when>
            <xsl:when test="name()='listOfFigures'">
                <xsl:value-of select="$name_figures"/>
            </xsl:when>
            <xsl:when test="name()='listOfTables'">
                <xsl:value-of select="$name_tables"/>
            </xsl:when>
            <!--  -->
            <!--   <xsl:when test="name()='index'">
                <xsl:value-of select="$name_index"/>
                </xsl:when> -->
            <xsl:when test="name()='entry'">
                <xsl:value-of select="$name_entry"/>
            </xsl:when>
            <xsl:when test="name()='goals'">
                <xsl:value-of select="$name_lObjectives"/>
            </xsl:when>
            <xsl:when test="name()='summary'">
                <xsl:value-of select="$name_summary"/>
            </xsl:when>
            <xsl:when test="name()='selfAssessment'">
                <xsl:value-of select="$name_selfAssessment"/>
            </xsl:when>
            <xsl:when test="name()='bibliography'">
                <xsl:value-of select="$name_bibliography"/>
            </xsl:when>
            <xsl:when test="name()='furtherReading'">
                <xsl:value-of select="$name_furtherReading"/>
            </xsl:when>
            <xsl:when test="name()='metadata' and $isnavigation='yes'">
                <xsl:value-of select="$name_metadata"/>
            </xsl:when>
            <xsl:when test="name()='metadata'">
                <xsl:value-of select="$name_metadata"/>
                <xsl:text> "</xsl:text>
                <xsl:value-of select="/elml:lesson/@title"/>
                <xsl:text>"</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>An ERROR occurred, please contact the webmaster! </xsl:text>
                <xsl:value-of select="$contact"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="elml:Title">
        <xsl:if test="@title">
            <fo:block font-size="{$fontsize}" line-height="{$lineheight}" font-weight="{$fontweighttitle}" space-before="{$lineheight}" keep-with-next.within-page="always">
                <xsl:value-of select="@title"/>
            </fo:block>
        </xsl:if>
    </xsl:template>
    <xsl:template match="elml:lesson">
        <fo:block>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
    <xsl:template match="elml:link">
        <xsl:param name="label" select="@targetLabel"/>
        <xsl:param name="TempURL">
            <xsl:choose>
                <xsl:when test="not((@role='student') or (@role=$role) or (not (@role)))">
                    <xsl:text>none</xsl:text>
                </xsl:when>
                <xsl:when test="starts-with(@uri, 'http') or starts-with(@uri, 'mailto:')">
                    <xsl:value-of select="@uri"/>
                </xsl:when>
                <xsl:when test="@uri">
                    <xsl:value-of select="$server"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="/elml:lesson/@label"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$lang"/>
                    <xsl:choose>
                        <xsl:when test="starts-with(@uri, '..')">
                            <xsl:value-of select="substring-after(@uri, '..')"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>/text/</xsl:text>
                            <xsl:value-of select="@uri"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>none</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:param>
        <xsl:choose>
            <xsl:when test="$TempURL='none'">
                <xsl:apply-templates/>
            </xsl:when>
            <xsl:when test="((boolean(name(preceding-sibling::node()[1])) or boolean(name(following-sibling::node()[1]))) and not(../text())) or (count(../*)=number('1') and (name(parent::node())='look' or name(parent::node())='act' or name(parent::node())='clarify'))">
                <fo:table table-layout="fixed" width="100%" border-style="solid" border-width="0.5pt" border-color="white">
                    <fo:table-column column-width="proportional-column-width(5)"/>
                    <fo:table-column column-width="proportional-column-width(50)"/>
                    <fo:table-column column-width="proportional-column-width(10)"/>
                    <fo:table-column column-width="proportional-column-width(10)"/>
                    <fo:table-column column-width="proportional-column-width(25)"/>
                    <fo:table-body>
                        <fo:table-row>
                            <xsl:if test="@icon and not($layout='none')">
                                <fo:table-cell padding="3pt" display-align="before" width="30px">
                                    <fo:block>
                                        <fo:external-graphic scaling="uniform" content-height="30px" content-width="30px" height="30px" width="30px">
                                            <xsl:attribute name="src">
                                                <xsl:value-of select="$pathRoot"/>
                                                <xsl:text>/_templates/</xsl:text>
                                                <xsl:value-of select="$layout"/>
                                                <xsl:text>/icons/</xsl:text>
                                                <xsl:value-of select="@icon"/>
                                                <xsl:text>.</xsl:text>
                                                <xsl:value-of select="$icon_filetype"/>
                                            </xsl:attribute>
                                        </fo:external-graphic>
                                    </fo:block>
                                </fo:table-cell>
                            </xsl:if>
                            <fo:table-cell padding="3pt" display-align="before">
                                <xsl:if test="not(@icon) or $layout='none'">
                                    <xsl:attribute name="number-columns-spanned">2</xsl:attribute>
                                </xsl:if>
                                <fo:block>
                                    <xsl:choose>
                                        <xsl:when test="not((@role='student') or (@role=$role) or (not (@role)))">
                                            <xsl:apply-templates/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <fo:basic-link color="blue">
                                                <xsl:choose>
                                                    <xsl:when test="starts-with($TempURL, 'http') or starts-with($TempURL, 'mailto:')">
                                                        <xsl:attribute name="external-destination">
                                                            <xsl:value-of select="$TempURL"/>
                                                        </xsl:attribute>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:attribute name="internal-destination">
                                                            <xsl:value-of select="$TempURL"/>
                                                        </xsl:attribute>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                                <xsl:apply-templates/>
                                            </fo:basic-link>
                                            <xsl:if test="$display_links='yes'">
                                                <fo:block font-size="0.8em">
                                                    <xsl:text> [</xsl:text>
                                                    <xsl:choose>
                                                        <xsl:when test="starts-with($TempURL, 'http')">
                                                            <xsl:value-of select="$TempURL"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:value-of select="$name_internalLink"/>
                                                            <xsl:text> </xsl:text>
                                                            <xsl:choose>
                                                                <xsl:when test="@targetLesson">
                                                                    <xsl:value-of select="$name_lesson"/>
                                                                    <xsl:text> </xsl:text>
                                                                    <xsl:value-of select="$TempURL"/>
                                                                </xsl:when>
                                                                <xsl:when test="@targetLabel">
                                                                    <xsl:value-of select="$name_page"/>
                                                                    <xsl:text> </xsl:text>
                                                                    <fo:page-number-citation>
                                                                        <xsl:attribute name="ref-id">
                                                                            <xsl:value-of select="$TempURL"/>
                                                                        </xsl:attribute>
                                                                    </fo:page-number-citation>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:text> URI </xsl:text>
                                                                    <xsl:value-of select="@uri"/>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <xsl:text>] </xsl:text>
                                                </fo:block>
                                            </xsl:if>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell padding="3pt" display-align="before" text-align="end">
                                <fo:block>
                                    <xsl:if test="@size">
                                        <xsl:value-of select="@size"/>
                                    </xsl:if>
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell padding="3pt" display-align="before">
                                <fo:block>
                                    <xsl:if test="@type">
                                        <xsl:value-of select="@type"/>
                                    </xsl:if>
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell padding="3pt" display-align="before">
                                <fo:block>
                                    <xsl:if test="@legend">
                                        <xsl:value-of select="@legend"/>
                                    </xsl:if>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </fo:table-body>
                </fo:table>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="empty(text())">
                        <xsl:value-of select="//*[@label=$label]/@title"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <fo:basic-link color="blue">
                            <xsl:attribute name="external-destination">
                                <xsl:value-of select="$TempURL"/>
                            </xsl:attribute>
                            <xsl:apply-templates/>
                        </fo:basic-link>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:if test="$display_links='yes'">
                    <fo:inline font-size="0.8em">
                        <xsl:text> [</xsl:text>
                        <xsl:value-of select="$TempURL"/>
                        <xsl:if test="@size or @type or @legend">
                            <xsl:text> </xsl:text>
                            <xsl:if test="@legend">
                                <xsl:value-of select="@legend"/>
                                <xsl:text>. </xsl:text>
                            </xsl:if>
                            <xsl:if test="@size">
                                <xsl:value-of select="$name_size"/>
                                <xsl:text>: </xsl:text>
                                <xsl:value-of select="@size"/>
                                <xsl:text>. </xsl:text>
                            </xsl:if>
                            <xsl:if test="@type">
                                <xsl:value-of select="$name_type"/>
                                <xsl:text>: </xsl:text>
                                <xsl:value-of select="@type"/>
                                <xsl:text>. </xsl:text>
                            </xsl:if>
                        </xsl:if>
                        <xsl:text>] </xsl:text>
                    </fo:inline>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="elml:paragraph" mode="icon">
        <fo:block space-after="{$lineheight}*0.7">
            <xsl:call-template name="elml:Label"/>
            <xsl:choose>
                <xsl:when test="@cssClass='code'">
                    <fo:block font-family="Courier, monospace" font-size="110%" white-space-collapse="true" white-space-treatment="ignore-if-surrounding-linefeed" text-align="left" wrap-option="wrap">
                        <xsl:apply-templates mode="#default"/>
                    </fo:block>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates mode="#default"/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:block>
    </xsl:template>
</xsl:stylesheet>
